@@ -3,7 +3,7 @@
 ** Purpose:     wxWidgets wrapper around the SQLite3 embedded database library.
 ** Author:      Ulrich Telle
 ** Created:     2005-07-14
-** Copyright:   (c) 2005-2021 Ulrich Telle
+** Copyright:   (c) 2005-2023 Ulrich Telle
 ** License:     LGPL-3.0+ WITH WxWindows-exception-3.1
 */
 
@@ -46,6 +46,117 @@
 
 <dl>
 
+<dt><b>4.9.8</b> - <i>November 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.8.0 (SQLite version 3.44.1)</i><br>
+Added new cipher scheme Ascon-128 (Lightweight Authenticated Encryption)
+
+</dd>
+
+<dt><b>4.9.7</b> - <i>November 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.7.4 (SQLite version 3.44.0)</i><br>
+Prevent crashes due to uninitialized cipher tables (issue #113)
+
+</dd>
+
+<dt><b>4.9.6</b> - <i>October 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.7.0 (SQLite version 3.43.1)</i><br>
+
+</dd>
+
+<dt><b>4.9.5</b> - <i>September 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.6.5 (SQLite version 3.43.1)</i><br>
+
+</dd>
+
+<dt><b>4.9.4</b> - <i>May 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.6.3 (SQLite version 3.42.0)</i><br>
+
+</dd>
+
+<dt><b>4.9.3</b> - <i>March 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.6.1 (SQLite version 3.41.1)</i><br>
+
+</dd>
+
+<dt><b>4.9.2</b> - <i>February 2023</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.6.0 (SQLite version 3.41.0)</i><br>
+Enhanced method wxSQLite3Database::Open allowing to set the VFS to be used<br>
+Added method wxSQLite3Database::IsInterrupted<br>
+
+</dd>
+
+<dt><b>4.9.1</b> - <i>November 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.5.4 (SQLite version 3.40.0)</i><br>
+
+</dd>
+
+<dt><b>4.9.0</b> - <i>September 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.5.3 (SQLite version 3.39.3)</i><br>
+
+</dd>
+
+<dt><b>4.8.2</b> - <i>July 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.4.6 (SQLite version 3.39.1)</i><br>
+
+</dd>
+
+<dt><b>4.8.1</b> - <i>May 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.4.3 (SQLite version 3.38.5)</i><br>
+
+</dd>
+
+<dt><b>4.8.0</b> - <i>April 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.4.2 (SQLite version 3.38.3)</i><br>
+
+</dd>
+
+<dt><b>4.7.9</b> - <i>April 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.10 (SQLite version 3.38.2)</i><br>
+
+</dd>
+<dt><b>4.7.8</b> - <i>March 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.9 (SQLite version 3.38.1)</i><br>
+
+</dd>
+<dt><b>4.7.7</b> - <i>February 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.8 (SQLite version 3.38.0)</i><br>
+
+</dd>
+<dt><b>4.7.6</b> - <i>January 2022</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.7 (SQLite version 3.37.2)</i><br>
+
+</dd>
+<dt><b>4.7.5</b> - <i>November 2021</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.5 (SQLite version 3.37.0)</i><br>
+
+</dd>
+<dt><b>4.7.4</b> - <i>July 2021</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.4 (SQLite version 3.36.0)</i><br>
+
+</dd>
+<dt><b>4.7.3</b> - <i>June 2021</i></dt>
+<dd>
+Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.3 (SQLite version 3.36.0)</i><br>
+
+</dd>
 <dt><b>4.7.2</b> - <i>May 2021</i></dt>
 <dd>
 Upgrade to <i>SQLite3 Multiple Ciphers version 1.3.2 (SQLite version 3.35.5)</i><br>
